@@ -7,9 +7,9 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.91';
+our $VERSION = '0.92';
 
-use Class::MOP;
+use Devel::PPPort 3.42;
 use Dist::Zilla 6.0;
 use Path::Iterator::Rule;
 
@@ -831,7 +831,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 SYNOPSIS
 
